@@ -1184,8 +1184,6 @@ msaClustalW <- function(inputSeqs,
         perm <- match(names(out@unmasked), names(inputSeqs))
         names(out@unmasked) <- inputSeqNames[perm]
     }
-    else
-        names(out@unmasked) <- NULL
 
     standardParams <- list(gapOpening=gapOpening,
                            gapExtension=gapExtension,
